import os
import unittest

from ashe import read, write


class FileTest(unittest.TestCase):
    def setUp(self) -> None:
        self.data = "123"
        self.path = "./test/test.txt"

    def test_write_and_read(self) -> None:
        write(self.path, self.data)
        self.assertEqual(read(self.path), self.data)

    def tearDown(self) -> None:
        os.remove(self.path)


if __name__ == "__main__":
    unittest.main()



import unittest

from ashe import merge, remove


class DictTest(unittest.TestCase):
    def setUp(self) -> None:
        self.dict1 = {"1": 1}
        self.dict2 = {"2": 2}
        self.dict3 = {"1": 1, "2": 2}

    def test_merge(self) -> None:
        self.assertEqual(merge(self.dict1, self.dict2), self.dict3)

    def test_remove(self) -> None:
        self.assertEqual(remove("1", self.dict3), self.dict2)


if __name__ == "__main__":
    unittest.main()



import unittest
from datetime import datetime, timedelta

from ashe import today, yesterday, tomorrow, get_interval_days


class DateTest(unittest.TestCase):
    def setUp(self) -> None:
        self.today = str(datetime.today().date())
        self.yesterday = str(datetime.today().date() + timedelta(days=-1))
        self.tomorrow = str(datetime.today().date() + timedelta(days=1))
        self.today_date = datetime.fromisoformat(self.today).date()
        self.yesterday_date = datetime.fromisoformat(self.yesterday).date()
        self.tomorrow_date = datetime.fromisoformat(self.tomorrow).date()

        self.interval_days = {
            "start": "2022-10-01",
            "end": "2022-10-03",
            "interval": 3,
            "days": ["2022-10-01", "2022-10-02", "2022-10-03"],
            "latest_days": list(reversed([str(datetime.today().date() - timedelta(days=i))
                                          for i in range(3)]))
        }

    def test_date(self) -> None:
        self.assertEqual(self.today, today())
        self.assertEqual(self.today_date, today("date"))
        self.assertEqual(self.yesterday, yesterday())
        self.assertEqual(self.yesterday_date, yesterday("date"))
        self.assertEqual(self.tomorrow, tomorrow())
        self.assertEqual(self.tomorrow_date, tomorrow("date"))

        self.assertEqual(
            self.interval_days["days"],
            get_interval_days(start=self.interval_days["start"], end=self.interval_days["end"])
        )
        self.assertEqual(
            self.interval_days["days"],
            get_interval_days(start=self.interval_days["start"], interval=self.interval_days["interval"])
        )
        self.assertEqual(
            self.interval_days["days"],
            get_interval_days(end=self.interval_days["end"], interval=self.interval_days["interval"])
        )
        self.assertEqual(
            self.interval_days["latest_days"],
            get_interval_days(interval=self.interval_days["interval"])
        )


if __name__ == "__main__":
    unittest.main()



import unittest

from ashe import find


class StrTest(unittest.TestCase):
    def setUp(self) -> None:
        self.input1 = "小明"
        self.input2 = "小明喜欢小红，小红却喜欢小黑，小黑偷偷暗恋小明！"
        self.output = [(0, 2), (21, 23)]

    def test_find(self) -> None:
        self.assertEqual(find(self.input1, self.input2), self.output)


if __name__ == "__main__":
    unittest.main()



import unittest

from ashe import size


class SysTest(unittest.TestCase):
    def setUp(self) -> None:
        self.input = 1
        self.output = 28

    def test_size(self) -> None:
        self.assertEqual(size(self.input), self.output)


if __name__ == "__main__":
    unittest.main()



import calendar
from datetime import datetime, timedelta

from typing import List, Union


def today(date_type: str = "str") -> Union[str, datetime.date]:
    _today = datetime.today().date()
    if date_type == "str":
        _today = str(_today)
    return _today


def yesterday(date_type: str = "str") -> Union[str, datetime.date]:
    _yesterday = today(date_type="date") + timedelta(days=-1)
    if date_type == "str":
        _yesterday = str(_yesterday)
    return _yesterday


def tomorrow(date_type: str = "str") -> Union[str, datetime.date]:
    _tomorrow = today(date_type="date") + timedelta(days=1)
    if date_type == "str":
        _tomorrow = str(_tomorrow)
    return _tomorrow


def week() -> int:
    return today(date_type="date").isocalendar()[1]


def month() -> int:
    return today(date_type="date").month


def year() -> int:
    return today(date_type="date").year


def get_interval_days(start: str = None, end: str = None, interval: int = None, reverse: bool = False,
                      date_type: str = "str") -> List[Union[str, datetime.date]]:
    if start is not None and end is not None and interval is not None:
        raise ValueError("three parameters (start end interval) cannot be present at the same time!")
    elif start is not None and end is not None:
        start_date = datetime.strptime(start, "%Y-%m-%d").date()
        end_date = datetime.strptime(end, "%Y-%m-%d").date()
        interval = (end_date - start_date).days + 1
    elif start is not None and interval is not None:
        start_date = datetime.strptime(start, "%Y-%m-%d").date()
    elif end is not None and interval is not None:
        end_date = datetime.strptime(end, "%Y-%m-%d").date()
        start_date = end_date - timedelta(days=interval - 1)
    elif start is None and end is None and interval is not None:
        end_date = datetime.today().date()
        start_date = end_date - timedelta(days=interval - 1)
    else:
        raise ValueError("please check parameter, single parameter only support interval!")

    day_list = []
    for day_delta in range(interval):
        _day = start_date + timedelta(days=day_delta)
        if date_type == "str":
            day_list.append(str(_day))
        else:
            day_list.append(_day)

    if reverse:
        day_list.reverse()

    return day_list


def get_week_days(offset: int = 0, date_type: str = "str") -> List[Union[str, datetime.date]]:
    _today = today(date_type="date")
    week_day = _today.weekday()
    _week_start_date = _today + timedelta(days=-week_day, weeks=offset)
    _week_end_date = _today + timedelta(days=-(week_day-6), weeks=offset)
    return get_interval_days(start=str(_week_start_date), end=str(_week_end_date), date_type=date_type)


def get_month_days(offset: int = 0, date_type: str = "str") -> List[Union[str, datetime.date]]:
    total_month = month() + offset
    _year = year() + (total_month-1)//12
    _month = 12 if total_month % 12 == 0 else total_month % 12

    month_days = calendar.monthrange(_year, _month)[1]
    _month_start_date = datetime(year=_year, month=_month, day=1).date()
    _month_end_date = datetime(year=_year, month=_month, day=month_days).date()
    return get_interval_days(start=str(_month_start_date), end=str(_month_end_date), date_type=date_type)



import unittest

from ashe import reverse, max_count


class DictTest(unittest.TestCase):
    def setUp(self) -> None:
        self.list = ["1", "3", "1", "4"]
        self.reverse_list = ["4", "1", "3", "1"]
        self.max_count_list = "1"

    def test_reverse(self) -> None:
        self.assertEqual(reverse(self.list), self.reverse_list)

    def test_max_count(self) -> None:
        self.assertEqual(max_count(self.list), self.max_count_list)


if __name__ == "__main__":
    unittest.main()



from typing import Dict


def merge(input_dict1: Dict, input_dict2: Dict) -> Dict:
    input_dict1.update(input_dict2)
    return input_dict1


def remove(key: str, input_dict: Dict) -> Dict:
    del input_dict[key]
    return input_dict



from typing import List, Any


def reverse(input_list: List) -> List:
    input_list.reverse()
    return input_list

def max_count(input_list: List) -> Any:
    return max(set(input_list), key=input_list.count)



from ._dict import merge, remove
from ._list import reverse, max_count
from ._sys import size
from ._str import find
from ._date import today, yesterday, tomorrow, week, month, year, get_interval_days, get_week_days, get_month_days
from ._file import read, write


__version__ = "0.0.8"

__all__ = [
    "merge",
    "remove",
    "reverse",
    "max_count",
    "size",
    "find",
    "read",
    "write",
    "today",
    "yesterday",
    "tomorrow",
    "week",
    "month",
    "year",
    "get_interval_days",
    "get_week_days",
    "get_month_days"
]



def read(file_path: str) -> str:
    with open(file_path, "r") as f_read:
        return f_read.read()


def write(file_path: str, file: str) -> None:
    with open(file_path, "w") as f_write:
        f_write.write(file)
